@@ -361,34 +361,36 @@ namespace mfront {
         os << "\t+ " << map_at(l, "description") << ": " << d.description
            << '\n';
       }
-      for (const auto& h : d.hypotheses) {
-        if (mb.isParameterName(h, d.name)) {
-          if (h == ModellingHypothesis::UNDEFINEDHYPOTHESIS) {
-            os << "\t+ " << map_at(l, "default value") << ": ";
-          } else {
-            os << "\t+ "
-               << map_at(l, "default value for") + " " +
-                      ModellingHypothesis::toString(h) + ": ";
-          }
-          if (d.type == "int") {
-            os << mb.getIntegerParameterDefaultValue(h, d.name);
-          } else if (d.type == "ushort") {
-            os << mb.getUnsignedShortParameterDefaultValue(h, d.name);
-          } else {
-            const auto& p =
-                mb.getBehaviourData(h).getParameters().getVariable(d.name);
-            if (p.arraySize == 1u) {
-              os << mb.getFloattingPointParameterDefaultValue(h, d.name);
+      if (!areParametersTreatedAsStaticVariables(mb)) {
+        for (const auto& h : d.hypotheses) {
+          if (mb.isParameterName(h, d.name)) {
+            if (h == ModellingHypothesis::UNDEFINEDHYPOTHESIS) {
+              os << "\t+ " << map_at(l, "default value") << ": ";
             } else {
-              for (unsigned short i = 0; i != p.arraySize;) {
-                os << mb.getFloattingPointParameterDefaultValue(h, d.name, i);
-                if (++i != p.arraySize) {
-                  os << " ";
+              os << "\t+ "
+                 << map_at(l, "default value for") + " " +
+                        ModellingHypothesis::toString(h) + ": ";
+            }
+            if (d.type == "int") {
+              os << mb.getIntegerParameterDefaultValue(h, d.name);
+            } else if (d.type == "ushort") {
+              os << mb.getUnsignedShortParameterDefaultValue(h, d.name);
+            } else {
+              const auto& p =
+                  mb.getBehaviourData(h).getParameters().getVariable(d.name);
+              if (p.arraySize == 1u) {
+                os << mb.getFloattingPointParameterDefaultValue(h, d.name);
+              } else {
+                for (unsigned short i = 0; i != p.arraySize;) {
+                  os << mb.getFloattingPointParameterDefaultValue(h, d.name, i);
+                  if (++i != p.arraySize) {
+                    os << " ";
+                  }
                 }
               }
             }
+            os << '\n';
           }
-          os << '\n';
         }
       }
       // codes blocks referring to the current variable
@@ -661,7 +663,7 @@ namespace mfront {
     if (!fd.date.empty()) {
       out << fd.date;
     } else {
-      out << "(unspecified)";
+      out << "(unspecified)\n";
     }
     if (mb.hasAttribute(BehaviourData::algorithm)) {
       out << "* algorithm: "
@@ -678,7 +680,7 @@ namespace mfront {
         }
       }
     } else {
-      out << "No description specified";
+      out << "No description specified\n";
     }
     //
     std::ifstream f(this->file);
@@ -689,9 +691,9 @@ namespace mfront {
     out << '\n'
         << "## Source code\n"
         << '\n'
-        << "~~~~ {#" << mb.getClassName() << " .cpp .numberLines}\n"
+        << "~~~~{#" << mb.getClassName() << " .cpp .numberLines}\n"
         << f.rdbuf() << '\n'
-        << "~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n"
+        << "~~~~\n"
         << '\n';
   }  // end of BehaviourDocumentationGenerator::writeWebOutput
 
@@ -772,9 +774,11 @@ namespace mfront {
               getData(mb, &BehaviourData::getExternalStateVariables),
               this->standalone);
     out << '\n';
-    if (mb.hasParameters()) {
-      printData(out, mb, "Parameters",
-                getData(mb, &BehaviourData::getParameters), this->standalone);
+    if (!areParametersTreatedAsStaticVariables(mb)) {
+      if (mb.hasParameters()) {
+        printData(out, mb, "Parameters",
+                  getData(mb, &BehaviourData::getParameters), this->standalone);
+      }
     }
     out << '\n';
     printData(out, mb, "Local variables",
