@@ -38,6 +38,32 @@
 
 namespace mfront {
 
+  static void displayDefaultParameterValue(const BehaviourData& bd,
+                                           const VariableDescription& p) {
+    const auto& n = p.name;
+    if (p.getTypeFlag() == mfront::SupportedTypes::SCALAR) {
+      if (p.arraySize == 1) {
+        std::cout << bd.getFloattingPointParameterDefaultValue(n) << '\n';
+      } else {
+        for (unsigned short i = 0; i != p.arraySize;) {
+          std::cout << bd.getFloattingPointParameterDefaultValue(n, i);
+          if (++i != p.arraySize) {
+            std::cout << " ";
+          }
+        }
+        std::cout << '\n';
+      }
+    } else if (p.type == "int") {
+      std::cout << bd.getIntegerParameterDefaultValue(n) << '\n';
+    } else if (p.type == "ushort") {
+      std::cout << bd.getUnsignedShortParameterDefaultValue(n) << '\n';
+    } else {
+      tfel::raise(
+          "displayDefaultParameterValue: "
+          "unsupported parameter type");
+    }
+  }  // end of displayDefaultParameterValue
+
   static const MaterialKnowledgeAttribute& getAttribute(
       const std::string& n,
       const BehaviourDescription& d,
@@ -787,6 +813,11 @@ namespace mfront {
           }
           cout << endl;
         }
+        if (areParametersTreatedAsStaticVariables(bd)) {
+          for (const auto& v : d.getParameters()) {
+            QueryHandlerBase::displayVariable(v);
+          }
+        }
       };
       this->queries.emplace_back("static-variables", nq);
     } else if (qn == "--auxiliary-state-variables") {
@@ -823,9 +854,16 @@ namespace mfront {
                                  this->generateVariablesListQuery<
                                      &BehaviourData::getLocalVariables>());
     } else if (qn == "--parameters") {
-      this->queries.emplace_back(
-          "parameters",
-          this->generateVariablesListQuery<&BehaviourData::getParameters>());
+      auto nq = [](const FileDescription&, const BehaviourDescription& bd,
+                   const Hypothesis h) {
+        if (!areParametersTreatedAsStaticVariables(bd)) {
+          const auto& d = bd.getBehaviourData(h);
+          for (const auto& v : d.getParameters()) {
+            QueryHandlerBase::displayVariable(v);
+          }
+        }
+      };
+      this->queries.emplace_back("parameters", nq);
     } else if (qn == "--attributes") {
       this->queries.push_back(
           {"attributes", [](const FileDescription&,
@@ -912,10 +950,12 @@ namespace mfront {
           {"parameters-file",
            [](const FileDescription&, const BehaviourDescription& d,
               const Hypothesis h) {
-             if (h != ModellingHypothesis::UNDEFINEDHYPOTHESIS) {
-               cout << mfront::getParametersFileName(d, h) << '\n';
-             } else {
-               cout << mfront::getParametersFileName(d) << '\n';
+             if (!areParametersTreatedAsStaticVariables(d)) {
+               if (h != ModellingHypothesis::UNDEFINEDHYPOTHESIS) {
+                 cout << mfront::getParametersFileName(d, h) << '\n';
+               } else {
+                 cout << mfront::getParametersFileName(d) << '\n';
+               }
              }
            }});
     } else {
@@ -1066,44 +1106,37 @@ namespace mfront {
     } else if (qn == "--parameter-type") {
       auto l = [o](const FileDescription&, const BehaviourDescription& d,
                    const Hypothesis h) {
-        const auto& bd = d.getBehaviourData(h);
-        const auto& p = bd.getParameterDescriptionByExternalName(o);
-        cout << p.type << '\n';
+        if (!areParametersTreatedAsStaticVariables(d)) {
+          const auto& bd = d.getBehaviourData(h);
+          const auto& p = bd.getParameterDescriptionByExternalName(o);
+          cout << p.type << '\n';
+        }
       };
       this->queries.push_back({"parameter-type", l});
     } else if (qn == "--parameter-default-value") {
       auto l = [o](const FileDescription&, const BehaviourDescription& d,
                    const Hypothesis h) {
+        if (areParametersTreatedAsStaticVariables(d)) {
+          return;
+        }
         const auto& bd = d.getBehaviourData(h);
         const auto& p = bd.getParameterDescriptionByExternalName(o);
-        const auto& n = p.name;
-        if (p.getTypeFlag() == mfront::SupportedTypes::SCALAR) {
-          if (p.arraySize == 1) {
-            cout << bd.getFloattingPointParameterDefaultValue(n) << '\n';
-          } else {
-            for (unsigned short i = 0; i != p.arraySize;) {
-              cout << bd.getFloattingPointParameterDefaultValue(n, i);
-              if (++i != p.arraySize) {
-                cout << " ";
-              }
-            }
-            cout << '\n';
-          }
-        } else if (p.type == "int") {
-          cout << bd.getIntegerParameterDefaultValue(n) << '\n';
-        } else if (p.type == "ushort") {
-          cout << bd.getUnsignedShortParameterDefaultValue(n) << '\n';
-        } else {
-          tfel::raise(
-              "Behaviour::treatStandardQuery2 : "
-              "unsupported parameter type");
-        }
+        displayDefaultParameterValue(bd, p);
       };
       this->queries.push_back({"parameter-default-value", l});
     } else if (qn == "--static-variable-value") {
       auto l = [o](const FileDescription&, const BehaviourDescription& d,
                    const Hypothesis h) {
         const auto& bd = d.getBehaviourData(h);
+        if (areParametersTreatedAsStaticVariables(d)) {
+          const auto& parameters = bd.getParameters();
+          const auto p = findByExternalName(parameters, o);
+          if (p != parameters.end()) {
+            const auto& v = parameters.getVariableByExternalName(o);
+            displayDefaultParameterValue(bd, v);
+            return;
+          }
+        }
         for (const auto& sv : bd.getStaticVariables()) {
           if (sv.name == o) {
             std::cout << sv.value << '\n';
