@@ -229,8 +229,8 @@ static void listOptions(std::ostream& os) {
 }  // end of listOptions
 
 [[noreturn]] static void treatVersion() {
-  std::cout << "tfel-config " << VERSION
-            << " (svn revision : " << TFEL_SVN_REVISION << ")" << std::endl;
+  std::cout << "tfel-config " << VERSION << " (git hash: " << TFEL_GIT_HASH
+            << ")" << std::endl;
   std::exit(EXIT_SUCCESS);
 }  // end of treatHelp
 
@@ -542,9 +542,15 @@ int main(const int argc, const char* const* const argv) {
 
     if (compilerflags) {
       std::cout << COMPILER_FLAGS << " " << COMPILER_CXXFLAGS << " ";
+      const auto* const cxx_standard =
+          getenv("TFEL_CXX_STANDARD_COMPILER_FLAG");
+      if (cxx_standard != nullptr) {
+        std::cout << cxx_standard << " ";
+      } else {
 #if (defined __GNUC__) || (defined __clang__) || (defined __INTEL_COMPILER)
-      std::cout << "-std=c++17 ";
+        std::cout << "-std=c++17 ";
 #endif
+      }
     }
 
     if (debugflags) {
